@@ -45,7 +45,7 @@ public:
         }
         mainLayout->addWidget(mView);
         q->connect(mView, &EmailAddressSelectionWidget::doubleClicked, q, &QDialog::accept);
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, q);
         QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
         okButton->setDefault(true);
         okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -73,8 +73,8 @@ public:
         group.writeEntry("Size", q->size());
     }
 
-    EmailAddressSelectionDialog *q;
-    EmailAddressSelectionWidget *mView;
+    EmailAddressSelectionDialog *q = nullptr;
+    EmailAddressSelectionWidget *mView = nullptr;
 };
 
 EmailAddressSelectionDialog::EmailAddressSelectionDialog(QWidget *parent)
